@@ -25,8 +25,6 @@ describe 'barbican::api' do
 
     let :default_params do
       {
-        :bind_host                                     => '0.0.0.0',
-        :bind_port                                     => '9311',
         :default_transport_url                         => '<SERVICE DEFAULT>',
         :rpc_response_timeout                          => '<SERVICE DEFAULT>',
         :control_exchange                              => '<SERVICE DEFAULT>',
@@ -38,6 +36,10 @@ describe 'barbican::api' do
         :rabbit_heartbeat_rate                         => '<SERVICE DEFAULT>',
         :rabbit_heartbeat_in_pthread                   => '<SERVICE DEFAULT>',
         :rabbit_ha_queues                              => '<SERVICE DEFAULT>',
+        :rabbit_quorum_queue                           => '<SERVICE DEFAULT>',
+        :rabbit_quorum_delivery_limit                  => '<SERVICE DEFAULT>',
+        :rabbit_quorum_max_memory_length               => '<SERVICE DEFAULT>',
+        :rabbit_quorum_max_memory_bytes                => '<SERVICE DEFAULT>',
         :amqp_durable_queues                           => '<SERVICE DEFAULT>',
         :max_allowed_secret_in_bytes                   => '<SERVICE DEFAULT>',
         :max_allowed_request_size_in_bytes             => '<SERVICE DEFAULT>',
@@ -73,8 +75,6 @@ describe 'barbican::api' do
     [
       {},
       {
-        :bind_host                                     => '127.0.0.1',
-        :bind_port                                     => '9312',
         :default_transport_url                         => 'rabbit://bugs:bugs_bunny@localhost:1234/rabbithost',
         :rpc_response_timeout                          => '120',
         :control_exchange                              => 'barbican',
@@ -86,6 +86,10 @@ describe 'barbican::api' do
         :rabbit_heartbeat_rate                         => '10',
         :rabbit_heartbeat_in_pthread                   => true,
         :rabbit_ha_queues                              => true,
+        :rabbit_quorum_queue                           => true,
+        :rabbit_quorum_delivery_limit                  => 3,
+        :rabbit_quorum_max_memory_length               => 5,
+        :rabbit_quorum_max_memory_bytes                => 1073741824,
         :amqp_durable_queues                           => true,
         :enable_queue                                  => true,
         :queue_namespace                               => 'barbican1',
@@ -166,19 +170,23 @@ describe 'barbican::api' do
             :topics        => param_hash[:notification_topics]
           )
           is_expected.to contain_oslo__messaging__rabbit('barbican_config').with(
-            :rabbit_use_ssl              => param_hash[:rabbit_use_ssl],
-            :heartbeat_timeout_threshold => param_hash[:rabbit_heartbeat_timeout_threshold],
-            :heartbeat_rate              => param_hash[:rabbit_heartbeat_rate],
-            :heartbeat_in_pthread        => param_hash[:rabbit_heartbeat_in_pthread],
-            :kombu_reconnect_delay       => param_hash[:kombu_reconnect_delay],
-            :kombu_failover_strategy     => param_hash[:kombu_failover_strategy],
-            :amqp_durable_queues         => param_hash[:amqp_durable_queues],
-            :kombu_compression           => param_hash[:kombu_compression],
-            :kombu_ssl_ca_certs          => param_hash[:kombu_ssl_ca_certs],
-            :kombu_ssl_certfile          => param_hash[:kombu_ssl_certfile],
-            :kombu_ssl_keyfile           => param_hash[:kombu_ssl_keyfile],
-            :kombu_ssl_version           => param_hash[:kombu_ssl_version],
-            :rabbit_ha_queues            => param_hash[:rabbit_ha_queues],
+            :rabbit_use_ssl                  => param_hash[:rabbit_use_ssl],
+            :heartbeat_timeout_threshold     => param_hash[:rabbit_heartbeat_timeout_threshold],
+            :heartbeat_rate                  => param_hash[:rabbit_heartbeat_rate],
+            :heartbeat_in_pthread            => param_hash[:rabbit_heartbeat_in_pthread],
+            :kombu_reconnect_delay           => param_hash[:kombu_reconnect_delay],
+            :kombu_failover_strategy         => param_hash[:kombu_failover_strategy],
+            :amqp_durable_queues             => param_hash[:amqp_durable_queues],
+            :kombu_compression               => param_hash[:kombu_compression],
+            :kombu_ssl_ca_certs              => param_hash[:kombu_ssl_ca_certs],
+            :kombu_ssl_certfile              => param_hash[:kombu_ssl_certfile],
+            :kombu_ssl_keyfile               => param_hash[:kombu_ssl_keyfile],
+            :kombu_ssl_version               => param_hash[:kombu_ssl_version],
+            :rabbit_ha_queues                => param_hash[:rabbit_ha_queues],
+            :rabbit_quorum_queue             => param_hash[:rabbit_quorum_queue],
+            :rabbit_quorum_delivery_limit    => param_hash[:rabbit_quorum_delivery_limit],
+            :rabbit_quorum_max_memory_length => param_hash[:rabbit_quorum_max_memory_length],
+            :rabbit_quorum_max_memory_bytes  => param_hash[:rabbit_quorum_max_memory_bytes],
           )
         end
 
