@@ -99,11 +99,7 @@ describe 'barbican::plugins::kmip' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge(OSDefaults.get_facts({
-          :processorcount => 8,
-          :fqdn           => 'some.host.tld',
-          :concat_basedir => '/var/lib/puppet/concat',
-        }))
+        facts.merge(OSDefaults.get_facts())
       end
 
       it_configures 'barbican plugins kmip'
